@@ -58,19 +58,23 @@
 
 #include "Multimedia/audiorecorder.h"
 
-#include "Whatsapp/util/utilities.h"
-#include "Whatsapp/util/datetimeutilities.h"
+#include "util/utilities.h"
+#include "util/datetimeutilities.h"
 #include "Whatsapp/ioexception.h"
 
 #include "hildon-input-method/hildon-im-protocol.h"
 
-#include "Whatsapp/util/rfc6234/sha224-256.c"
+#include "util/rfc6234/sha224-256.c"
 
 #include "client.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
+// Solve clash between Xlib FocusIn and QEvent::FocusIn
+enum { XFocusIn = FocusIn };
+#undef FocusIn
+
 #define TEXTEDIT_HEIGHT     70
 #define MAX_FILE_SIZE       16777216
 
@@ -97,8 +101,10 @@ ChatWindow::ChatWindow(Contact *contact, QWidget *parent) :
             this,SLOT(sendVoiceNotePlayed(FMessage)));
     connect(ui->scrollArea,SIGNAL(forwardMessage(FMessage)),
             this,SLOT(forwardMessageRequested(FMessage)));
+    connect(ui->scrollArea,SIGNAL(deleteMessage(FMessage)),
+            this,SLOT(deleteMessage(FMessage)));
     connect(ui->sendButton,SIGNAL(clicked()),this,SLOT(sendButtonClicked()));
-    connect(ui->sendButton,SIGNAL(pressed()),this,SLOT(startRecording()));
+    connect(ui->recordButton,SIGNAL(pressed()),this,SLOT(startRecording()));
     connect(ui->selectEmojiButton,SIGNAL(clicked()),
             ui->textEdit,SLOT(selectEmojiButtonClicked()));
 
@@ -203,6 +209,8 @@ void ChatWindow::readMoreLogLines()
 
 void ChatWindow::setMessagesAsRead()
 {
+    if(!isActiveWindow()) return;
+
     FMessage msg = logger.lastMessage();
     if(msg.key.from_me || msg.status == FMessage::ReceivedByTarget) return;
 
@@ -303,13 +311,11 @@ void ChatWindow::textChanged()
 {
     if (!ui->textEdit->document()->isEmpty())
     {
-        ui->sendButton->setText("Send");
-        ui->sendButton->setIcon(QIcon());
+        ui->recordButton->setVisible(false);
     }
     else
     {
-        ui->sendButton->setText("");
-        ui->sendButton->setIcon(QIcon("/usr/share/yappari/icons/48x48/voice_overlay_icon.png"));
+        ui->recordButton->setVisible(true);
     }
 }
 
@@ -359,6 +365,12 @@ void ChatWindow::paused(QString participant)
 
 bool ChatWindow::eventFilter(QObject *obj, QEvent *event)
 {
+    if(event->type() == QEvent::WindowActivate)
+    {
+        setMessagesAsRead();
+        return true;
+    }
+
     if (obj == ui->centralwidget)
     {
         if (event->type() == QEvent::MouseButtonPress)
@@ -844,7 +856,7 @@ void ChatWindow::startRecording()
 
         AudioRecorder *recorder = new AudioRecorder(Client::voiceCodec, this);
 
-        connect(ui->sendButton,SIGNAL(released()),recorder,SLOT(stop()));
+        connect(ui->recordButton,SIGNAL(released()),recorder,SLOT(stop()));
         connect(recorder,SIGNAL(finished(QString,int)),this,SLOT(finishedRecording(QString,int)));
         connect(recorder,SIGNAL(progress(int)),this,SLOT(updateRecordingTime(int)));
 
@@ -916,3 +928,16 @@ void ChatWindow::forwardMessageRequested(FMessage message)
 {
     emit forwardMessage(message);
 }
+
+void ChatWindow::deleteMessage(FMessage message)
+{
+    QMessageBox msg(this);
+
+    msg.setText("Are you sure you want to permanentl delete this message from the log?");
+    msg.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);
+
+    if (msg.exec() == QMessageBox::Yes)
+    {
+        logger.deleteMessage(message);
+    }
+}
