@@ -35,7 +35,7 @@
 #include "globalconstants.h"
 #include "chatlogger.h"
 
-#include "Whatsapp/util/utilities.h"
+#include "util/utilities.h"
 
 #define MAX_MESSAGES               7
 #define LOG_VERSION                7
@@ -427,6 +427,7 @@ QList<FMessage> ChatLogger::lastMessages()
 
     while (query.next()) {
         FMessage msg = sqlQueryResultToFMessage(jid,query);
+
         list.append(msg);
 
         lastId = query.value(LOG_LOCALID).toInt();
