@@ -30,17 +30,11 @@
 #include <QRegExp>
 #include <QTime>
 
-#include "Whatsapp/util/qtmd5digest.h"
-#include "Whatsapp/util/utilities.h"
-#include "Whatsapp/util/datetimeutilities.h"
+#include "util/qtmd5digest.h"
+#include "util/utilities.h"
+#include "util/datetimeutilities.h"
 #include "Whatsapp/protocoltreenodelistiterator.h"
 
-#include "Whatsapp/libaxolotl/util/keyhelper.h"
-#include "Whatsapp/libaxolotl/protocol/prekeywhispermessage.h"
-#include "Whatsapp/libaxolotl/protocol/whispermessage.h"  
-#include "Whatsapp/libaxolotl/whisperexception.h"
-
-
 #include "globalconstants.h"
 
 #include "connection.h"
@@ -80,8 +74,6 @@ Connection::Connection(QTcpSocket *socket, QString domain, QString resource,
     this->out = new BinTreeNodeWriter(socket,dictionary,this);
     this->in = new BinTreeNodeReader(socket,dictionary,this);
 
-    axolotlStore = new LiteAxolotlStore(AXOLOTL_DB_CONNECTION);
-
     connect(&connTimeout,SIGNAL(timeout()),this,SLOT(connectionTimeout()));
     connTimeout.start(CHECK_CONNECTION_INTERVAL);
 }
@@ -933,6 +925,7 @@ void Connection::parseMessageInitialTagAlreadyChecked(ProtocolTreeNode& messageN
                 attrs.insert("id", id);
                 attrs.insert("to", from);
                 attrs.insert("type", "error");
+                if(!participant.isEmpty()) attrs.insert("participant", participant);
                 messageNode.setAttributes(attrs);
 
                 attrs.clear();
