@@ -49,14 +49,10 @@
 #include "protocolexception.h"
 #include "loginexception.h"
 #include "keystream.h"
-#include "fmessage.h"
-#include "funstore.h"
+#include "FMessage/fmessage.h"
+#include "FMessage/funstore.h"
 #include "watokendictionary.h"
 
-#include "axolotl/liteaxolotlstore.h"
-#define AXOLOTL_DB_CONNECTION "qt_sql_axolotl_connection"
-
-
 // QtMobility namespace
 QTM_USE_NAMESPACE
 
@@ -266,9 +262,6 @@ public slots:
 
 private:
 
-    LiteAxolotlStore *axolotlStore;
-
-
     /** ***********************************************************************
      ** Private members
      **/
